.. _astro-source-snr:

Supernova Remnant Models
========================

Plot the evolution of radius of the SNR:

.. plot:: astro/source/plot_snr_radius_evolution.py
    :include-source:

Plot the evolution of the flux of the SNR above 1 TeV and at 1 kpc distance:

.. plot:: astro/source/plot_snr_brightness_evolution.py
    :include-source:
